@@ -142,13 +142,14 @@ class dyn_obj:
     The main building block of all dynamic visualizations 
     :param bpy.data.object obj: the Blender object that will be animated
     :param np.ndarray pa: the offset of the principal axes specified by the :param: ` euler_type:
+    :param tuple cog: the center of gravity as defined from the origin of the 3D model
     :param str euler_type: the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
     :param bpy.data.object parent: the Blender object parent of the original object 
     :param anim: class object that was used to initialize the animation
     :type anim: :class:`bpsci.core.init_anim`
         
     """
-    def __init__(self, obj, pa, euler_type, parent, anim):
+    def __init__(self, obj, pa, cog, euler_type, parent, anim):
         
 
         self.parent = parent
@@ -182,7 +183,7 @@ class dyn_obj:
         obj.parent = self.body.ob
         obj.scale = (self.scale, self.scale, self.scale)
 
-        self.body.static_6DOF(-self.quat, None, None, None)
+        self.body.static_6DOF(-self.quat, cog[0], cog[1], cog[2])
 
         self.name = obj.name
         """:type: `str`: the Blender object name of the original object"""
@@ -271,6 +272,7 @@ class dyn_vec:
         """:type: `bpy.data.object`: the actual arrow asset"""
         
         self.parent_rf.ob.location = offset
+        self.offset = offset
         vec.parent = self.parent_rf.ob
         vec.name = self.name
         
@@ -323,7 +325,7 @@ class dyn_vec:
             
             self.parent_rf.ob.scale = (mag_arrow, 1, 1)
                 
-            self.point_rf.ob.location = (cur_x, cur_y, cur_z)
+            self.point_rf.ob.location = (cur_x + self.offset[0], cur_y+self.offset[1], cur_z+self.offset[2])
             
             self.point_rf.ob.keyframe_insert(data_path='location', frame=cur_frame)
             self.parent_rf.ob.keyframe_insert(data_path='scale', frame=cur_frame)
